@@ -34,13 +34,14 @@ def get_index(channel_urls=(), prepend=True, platform=None,
 
     sddata = []
     index = []
+
     for idx, url in enumerate(real_urls):
         channel = Channel(url)
 
         full_url = channel.url(with_credentials=True) + '/' + repodata_fn
         full_path_cache = os.path.join(
-            create_cache_dir(),
-            cache_fn_url(full_url, repodata_fn))
+            api.create_cache_dir(),
+            api.cache_fn_url(full_url))
 
         sd = api.SubdirData(channel.name + '/' + channel.subdir,
                             full_url,
@@ -67,26 +68,34 @@ def init_api_context(use_mamba_experimental=False):
         context.quiet = True
         if use_mamba_experimental:
             context.json = False
-            context.dry_run = False
+            # context.dry_run = False
     api_ctx.set_verbosity(context.verbosity)
     api_ctx.quiet = context.quiet
     api_ctx.offline = context.offline
     api_ctx.local_repodata_ttl = context.local_repodata_ttl
     api_ctx.use_index_cache = context.use_index_cache
     api_ctx.always_yes = context.always_yes
+    api_ctx.channels = context.channels
+
     if context.ssl_verify == False:
         api_ctx.ssl_verify = "<false>"
     elif context.ssl_verify is not True:
         api_ctx.ssl_verify = context.ssl_verify
     api_ctx.target_prefix = context.target_prefix
+    api_ctx.root_prefix = context.root_prefix
+    api_ctx.conda_prefix = context.conda_prefix
+    api_ctx.pkgs_dirs = context.pkgs_dirs
+    api_ctx.envs_dirs = context.envs_dirs
 
-    api_ctx.read_timeout_secs = int(round(context.remote_read_timeout_secs))
+    # api_ctx.read_timeout_secs = int(round(context.remote_read_timeout_secs))
     api_ctx.connect_timeout_secs = int(round(context.remote_connect_timeout_secs))
     api_ctx.max_retries = context.remote_max_retries
     api_ctx.retry_backoff = context.remote_backoff_factor
+    api_ctx.add_pip_as_python_dependency = context.add_pip_as_python_dependency
 
 def to_package_record_from_subjson(channel, pkg, jsn_string):
     channel = channel
+    # print(channel, pkg, jsn_string)
     channel_url = channel.url(with_credentials=True)
     info = json.loads(jsn_string)
     info['fn'] = pkg
